@@ -432,6 +432,7 @@ class Human:
     def __init__(self, image_analysis):
         self.threshold = 2.5  # 置信度 2.5
         self.image_analysis = image_analysis
+        self.head = False  # 头是否存在，以此来判断 头顶是否存在
         if image_analysis.get('recognition'):  # 新版本ai识别结果
             self.threshold = 0.05
             image_analysis['human_pose'] = self.add_new_crop_point(image_analysis.get("recognition"),
@@ -441,8 +442,8 @@ class Human:
         self.human_body_width = None
         self.human_bodies_list = self.ai_human_pose(image_analysis.get('human_pose'))
 
-    @staticmethod
-    def calculate_mouth(ai_crop_point_dict):
+
+    def calculate_mouth(self, ai_crop_point_dict):
         """
         1.根据 眼镜 鼻子 计算嘴巴的位置
         2.根据眼睛鼻子判断 头顶是否要删除
@@ -459,8 +460,9 @@ class Human:
                 'top_site': (nose_x, mouth_y),
                 'bottom_site': (nose_x, mouth_y)
             }
+
         if 'eye' not in ai_crop_point_dict.keys() and 'nose' not in ai_crop_point_dict.keys() \
-                and 'human_top' in ai_crop_point_dict.keys():
+                and not self.head and 'human_top' in ai_crop_point_dict.keys():
             ai_crop_point_dict.pop('human_top')
 
         if 'ankle' not in ai_crop_point_dict.keys() and 'human_bottom' in ai_crop_point_dict.keys():
@@ -468,8 +470,7 @@ class Human:
 
         return ai_crop_point_dict
 
-    @staticmethod
-    def calculate_mandible_crop_point(face, human_keypoint_list):
+    def calculate_mandible_crop_point(self, face, human_keypoint_list):
         """
         在recognition face 内
         置信度小于0.8不可信
@@ -484,6 +485,9 @@ class Human:
 
         mandible_point = [-1, -1, 0]
 
+        # ['右踝', '右膝', '右臀', '左臀', '左膝', '左踝', '腰', '脊柱', '颈', '头', '右腕', '右肘', '右肩', '左肩', '左肘', '左腕']
+        r_ank, r_kne, r_hip, l_hip, l_kne, l_ank, pel, spi, nec, hea, r_wri, r_elb, r_sho, l_sho, l_elb, l_wri = human_keypoint_list
+
         # face 存在识别结果
         # 置信度小于0.8不可信
         if face and face.get('confidence', 0) >= 0.8:
@@ -501,11 +505,7 @@ class Human:
             mandible_point[2] = 1
             # print(mandible_point)
         else:
-            # ['右踝', '右膝', '右臀', '左臀', '左膝', '左踝', '腰', '脊柱', '颈', '头', '右腕', '右肘', '右肩', '左肩', '左肘', '左腕']
-            r_ank, r_kne, r_hip, l_hip, l_kne, l_ank, pel, spi, nec, hea, r_wri, r_elb, r_sho, l_sho, l_elb, l_wri = human_keypoint_list
-
             # print(r_sho, l_sho, pel, spi, nec)  # '右肩', '左肩' '腰', '脊柱', '颈'
-
             # 根据肩部和颈部计算下颚的点
             # 计算肩部点
             if r_sho[2] > 0.2 and l_sho[2] > 0.2:
@@ -624,6 +624,26 @@ class Human:
         if len(human_bodies_list) != len(human_pose_result):
             return human_pose
 
+        for i, human in enumerate(human_bodies_list):
+            # ['右踝', '右膝', '右臀', '左臀', '左膝', '左踝', '腰', '脊柱', '颈', '头', '右腕', '右肘', '右肩', '左肩', '左肘', '左腕']
+            r_ank, r_kne, r_hip, l_hip, l_kne, l_ank, pel, spi, nec, hea, r_wri, r_elb, r_sho, l_sho, l_elb, l_wri = human['keypoints']
+
+            if hea[2] > 0:
+                self.head = True
+            if len(human_pose_result[i]['keypoints']) == 17:
+                # 倒着insert 不会改变前面点的index
+                # 在recognition keypoints 内 index 为6 的是腰部
+                human_pose_result[i]['keypoints'].insert(self.HUMAN_BODY_KEY_POINTS.index('left_hip'),
+                                                         human['keypoints'][6])
+
+                # 在recognition face 内
+                # 置信度小于0.8不可信
+                # 嘴巴点 在 keypoints index 3 4
+                # 下巴点 在 bbox index  2 3
+                human_pose_result[i]['keypoints'].insert(self.HUMAN_BODY_KEY_POINTS.index('left_shoulder'),
+                                                         self.calculate_mandible_crop_point(human['face'],
+                                                                                            human['keypoints']))
+
         # 添加完裁剪点后，下面两个配置需要对应的改掉
         # 19 个 人体关键点对应关系
         self.HUMAN_BODY_KEY_POINTS = [
@@ -666,20 +686,6 @@ class Human:
             "ankle": ["left_ankle", "right_ankle"],
         }
 
-        for i, human in enumerate(human_bodies_list):
-            if len(human_pose_result[i]['keypoints']) == 17:
-                # 在recognition keypoints 内 index 为6 的是腰部
-                human_pose_result[i]['keypoints'].insert(self.HUMAN_BODY_KEY_POINTS.index('waist'),
-                                                         human['keypoints'][6])
-
-                # 在recognition face 内
-                # 置信度小于0.8不可信
-                # 嘴巴点 在 keypoints index 3 4
-                # 下巴点 在 bbox index  2 3
-                human_pose_result[i]['keypoints'].insert(self.HUMAN_BODY_KEY_POINTS.index('mandible'),
-                                                         self.calculate_mandible_crop_point(human['face'],
-                                                                                            human['keypoints']))
-
         human_pose_dict['result'] = human_pose_result
 
         human_pose = json.dumps(human_pose_dict)
