@@ -544,17 +544,40 @@ class ImageCrop:
     @staticmethod
     def _get_x_human_and_cloth(img):
         """左右取人体和衣服最靠外的点"""
-        human_box_top = img.crop_point.get('human_top',
-                                           {'top_site': [0, 0], 'bottom_site': [1, 1]})['top_site']
-        human_box_bottom = img.crop_point.get('human_bottom',
-                                              {'top_site': [0, 0], 'bottom_site': [1, 1]})['bottom_site']
-        cloth_box_top = img.crop_point.get('garment_top',
-                                           {'top_site': [0, 0], 'bottom_site': [1, 1]})['top_site']
-        cloth_box_bottom = img.crop_point.get('garment_bottom',
-                                              {'top_site': [0, 0], 'bottom_site': [1, 1]})['bottom_site']
+        # 衣服识别范围不存在,人的识别范围也不存在
+        human_x_flag = False
+        cloth_x_flag = False
+
+        if 'garment_top' in img.crop_point:
+            cloth_x_flag = True
+            cloth_box_top = img.crop_point.get('garment_top',
+                                               {'top_site': [0, 0], 'bottom_site': [1, 1]})['top_site']
+            cloth_box_bottom = img.crop_point.get('garment_bottom',
+                                                  {'top_site': [0, 0], 'bottom_site': [1, 1]})['bottom_site']
+
+        if 'human_top' in img.crop_point:
+            human_box_top = img.crop_point['human_top']['top_site']
+            human_box_bottom = img.crop_point['human_top']['bottom_site']
+            human_x_flag = True
+
+        elif 'human_bottom' in img.crop_point:
+            human_box_top = img.crop_point['human_bottom']['top_site']
+            human_box_bottom = img.crop_point['human_bottom']['bottom_site']
+            human_x_flag = True
+
+
+        if human_x_flag and cloth_x_flag:
+            crop_left = min(human_box_top[0], human_box_bottom[0], cloth_box_top[0], cloth_box_bottom[0])
+            crop_right = max(human_box_top[0], human_box_bottom[0], cloth_box_top[0], cloth_box_bottom[0])
+        elif human_x_flag and not cloth_x_flag:
+            crop_left = min(human_box_top[0], human_box_bottom[0])
+            crop_right = max(human_box_top[0], human_box_bottom[0])
+        elif not human_x_flag and  cloth_x_flag:
+            crop_left = min(cloth_box_top[0], cloth_box_bottom[0])
+            crop_right = max(cloth_box_top[0], cloth_box_bottom[0])
+        else:
+            crop_left = crop_right = 0.5
 
-        crop_left = min(human_box_top[0], human_box_bottom[0], cloth_box_top[0], cloth_box_bottom[0])
-        crop_right = max(human_box_top[0], human_box_bottom[0], cloth_box_top[0], cloth_box_bottom[0])
         return crop_left, crop_right
 
     def _from_img_get_top_site(self, crop_point, top_site):
